@@ -6,7 +6,7 @@
 #' @importFrom lsa cosine
 #' @importFrom lsa textmatrix
 #' @importFrom lsa lsa 
-genericSummary <- function(text,k,split=c(".","!","?"),min=5,breakdown=TRUE,...){
+genericSummary <- function(text,k,split=c(".","!","?"),min=5,breakdown=FALSE,...){
  
   #### Decompose the document D into individual sentences
   
