@@ -14,6 +14,16 @@ multicostring <- function(x,y,tvectors=tvectors,breakdown=FALSE){
   
   if(class(tvectors) == "matrix"){
     
+    if(class(x) != "character"){
+      x <- as.character(x)
+      message("Note: x converted to character")
+    }
+    
+    if(class(y) != "character"){
+      y <- as.character(y)
+      message("Note: y converted to character")
+    }
+    
     if(breakdown==TRUE){
       
       satz1 <- breakdown(x)
